prepares table of observational records into a sites x
species matrix for use in ecomix.
table_to_species_data(
observation_data,
site_id = "site_id",
species_id = "species_id",
measurement_id = NULL
)
make_mixture_data(species_data, covariate_data)data to be imported into R. A table of species occurrences and site records.
Name of column that contains site names /IDs.
Name of column that contains species information/ID.
Name of column that contains species observational data. eg, 'occurrence', 'abundance' or 'biomass'.
A character string providing the name of the column in data that contains the counts
A character string providing the name of the column in data that contains the binary occurence data
A sites x species matrix to used as species_data in ecomix
models.
A list containing the following elements:
A matrix of occurrence, counts, biomass, or...
The design matrix for the global covariates