R/package.R
ecomix.Rd
ecomix is a package for implementing species archetype models (SAM) and region of common profile models (RCP) in R. The main function is ecomix, which fits either a SAM or RCP based on input parameters.
ecomix
Useful links:
https://github.com/skiptoniam/ecomix
Maintainer: Skipton Woolley skip.woolley@csiro.au
Authors:
Scott Foster scott.foster@csiro.au
Piers Dunstan Piers.Dunstan@csiro.au