R/species_mix_s3-class.R
plot.species_mix.multifit.Rd
plot.species_mix.multifit
# S3 method for species_mix.multifit plot(x, type = c("BIC", "AIC", "logLik"), ...)
a fitted species_mix.multifit object.
What type of response to plot options are "BIC", "AIC" or "logLik".
Extra plotting arguments.
Plot BIC or other likelihood based indices from multiple fit object.