R/species_mix_s3-class.R
residuals.species_mix.RdThe randomised quantile residuals ("RQR", from Dunn and Smyth, 1996) are defined by their marginal distribution function (marginality is over other species observations within that site; see Woolley et al, in prep).
# S3 method for species_mix
residuals(object, ..., type = "RQR", quiet = FALSE)A returned species_mix model object.
additional calls for residual function
The type of residuals to estimate. Default is "RQR" (Random Quantile Residuals). But you can also simulate many Random Quantile Residuals using "SimRQR".
Print out residual issues.