A summary from a regional_mix object.
# S3 method for regional_mix
summary(object, ...)A regional_mix model object
ignored.
A table is printed that contains the coefficient values, their standard errors, and their z-statistic. The second and thrid columns may be unreliable for some parameters.