This function returns a list of terms objects, one for each formula in the species mix model.
Are the terms for the archetypes formula.
Are the terms for the species formula.
Are the terms for the all/bias formula.
# S3 method for species_mix
terms(x, ...)A species_mix model object
Ignored