plot.regional_mix_effects_data
a list of partial prediction data frames as generated by effects_data.
A fitted regional_mix model.
A regional_mix.bootstrap object. Default is NULL, no standard errors will be reported.
An option to do bootstrapping when plotting, this will be slow, better to run and save a bootstrap object and pass to the plotting function as boot.object.
Which RCPs to plot on the y-axis. Default is all RCPs.
Can be a subset, using the names stored in object$names$RCPs (e.g. "RCP_1").
is the confidence intervals for the standard errors.
Are the default colours for plotting the partial responses.
Is the colour of the confidence intervals in the response plots.
Default is NULL and will plot ylim within range of the response variable.
Extra plotting arguments.
Plots the partial dependence plots (marginal response curves) for focal covariates. Continuous covariates will be plotted as lines, factors will be plotted as dotplots. RCP predictions are probabilities, so unlike plot.species_mix_effects_data there is no link/response scale option.