simulate a Gaussian Markov Random Field from the Matern family. This is developed from the Rue & Held 2005 Algorithim 2.10.
rGMRF(x, y = x, sig2 = 1, rho = 0.5, nu = 1/2, nugget = NULL)vector of evenly spaced values in the x-direction
vector of evenly spaced values in the y-direction (default is the same as x)
gives the marginal variance of the process
is effective range/lengthscale
is smoothness for the Matern, can be either 1/2, 3/2, 5/2 if none of these then an error will be thrown.
is nugget variance. Default is NULL.